"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Locale = void 0;
var tslib_1 = require("tslib");
var flat_1 = tslib_1.__importDefault(require("flat"));
var deepmerge_1 = tslib_1.__importDefault(require("deepmerge"));
var Locale = /** @class */ (function () {
    function Locale(language, translations) {
        this.delimiter = '.';
        this.language = language;
        this._translations = translations;
    }
    Locale.prototype.getTranslations = function (useFlat) {
        if (useFlat === void 0) { useFlat = false; }
        if (useFlat) {
            return flat_1.default(this._translations, {
                delimiter: this.delimiter,
            });
        }
        return this._translations;
    };
    Locale.prototype.addPrefixToKeys = function (prefix) {
        var _this = this;
        var newTranslations = {};
        Object.keys(this._translations).forEach(function (key) {
            newTranslations["" + prefix + key] = _this._translations[key];
        });
        this._translations = newTranslations;
        return this._translations;
    };
    Locale.prototype.addTranslations = function (newTranslations) {
        this._translations = deepmerge_1.default(this._translations, newTranslations);
        return this._translations;
    };
    Locale.prototype.getEnum = function (enumDelimiter) {
        var _this = this;
        if (enumDelimiter === void 0) { enumDelimiter = '_'; }
        var result = '';
        result += "export enum Translations {\n";
        var pathList = getObjectPathList(this._translations);
        pathList.forEach(function (path) {
            result += "\t" + path.join(enumDelimiter) + " = '" + path.join(_this.delimiter) + "',\n";
        });
        result += "}\n";
        return result;
    };
    Locale.prototype.getTranslationsCount = function () {
        return Object.keys(this.getTranslations(true)).length;
    };
    return Locale;
}());
exports.Locale = Locale;
function getObjectPathList(target) {
    var result = [];
    function step(temp, path) {
        Object.keys(temp).forEach(function (key) {
            var value = temp[key];
            var newPath = path ? path.concat([key]) : [key];
            if (typeof value === 'object') {
                return step(value, newPath);
            }
            result.push(newPath);
        });
    }
    step(target);
    return result;
}
//# sourceMappingURL=locale.js.map